@@ -5,3 +5,5 @@ from . import coordinate_generator
 from . import access
 from . import folder_to_lib
 from . import platform_specific
+from .UniformConfigurations import UniformConfigurations
+from . import featurerecognition
